Module ops

Module ops 

Branch operations โ€” list, create, delete, checkout, and merge branches.

Functions

checkout_branch
Checkout an existing local branch by name.
checkout_remote_branch
Checkout a remote branch by creating a local tracking branch.
create_annotated_tag
Create an annotated Git tag with a tagger signature and message pointing at the given OID.
create_branch
Create a new local branch at HEAD with the given name.
create_branch_at_commit
Create a new local branch pointing at a specific commit OID.
create_tag
Create a lightweight Git tag pointing at the given OID.
delete_branch
Delete a local branch by name.
delete_remote_branch
Delete a remote branch using git push <remote> --delete <branch>.
list_branches
List all branches (local and remote) in the repository.
merge_branch
Merge a source branch into the current HEAD branch.
pull_rebase
Pull the current branch from a remote with --rebase.
push_branch
Push a local branch to a remote using git push.
rebase_onto
Rebase the current HEAD onto target (branch name or OID).
rename_branch
Rename a local branch.