pub fn get_commit_details(
repo: &Repository,
oid_str: &str,
) -> Result<CommitInfo>Expand description
Retrieve the full CommitInfo for a commit identified by its hex OID string.
pub fn get_commit_details(
repo: &Repository,
oid_str: &str,
) -> Result<CommitInfo>Retrieve the full CommitInfo for a commit identified by its hex OID string.