Diff operations — working-directory, staged, and per-commit diffs.
Functions
- get_
commit_ diff - Return the diff introduced by a specific commit (compared to its first parent).
- get_
commit_ file_ list - Return just the list of changed files for a commit — no hunk / line parsing.
- get_
single_ file_ diff - Return the diff for a single file within a commit.
- get_
staged_ diff - Return the diff of staged (index) changes against HEAD.
- get_
working_ dir_ diff - Return the diff of unstaged (working-directory) changes against the index.