Branch operations โ list, create, delete, checkout, and merge branches.
Functions
- checkout_
branch - Checkout an existing local branch by name.
- checkout_
remote_ branch - Checkout a remote branch by creating a local tracking branch.
- create_
annotated_ tag - Create an annotated Git tag with a tagger signature and message pointing at the given OID.
- create_
branch - Create a new local branch at HEAD with the given name.
- create_
branch_ at_ commit - Create a new local branch pointing at a specific commit OID.
- create_
tag - Create a lightweight Git tag pointing at the given OID.
- delete_
branch - Delete a local branch by name.
- delete_
remote_ branch - Delete a remote branch using
git push <remote> --delete <branch>. - list_
branches - List all branches (local and remote) in the repository.
- merge_
branch - Merge a source branch into the current HEAD branch.
- pull_
rebase - Pull the current branch from a remote with
--rebase. - push_
branch - Push a local branch to a remote using
git push. - rebase_
onto - Rebase the current HEAD onto
target(branch name or OID). - rename_
branch - Rename a local branch.