Diff operations — working-directory, staged, and per-commit diffs.
Functions
- checkout_
file_ at_ commit - Restore a specific file from a commit to the working directory.
- diff_
file_ commit_ vs_ workdir - Return the diff of a file between a specific commit and the current working directory.
- file_
list_ commit_ vs_ workdir - Get the list of files that differ between a commit and the current working directory.
- get_
commit_ diff - Return the diff introduced by a specific commit (compared to its first parent).
- get_
commit_ file_ list - Return just the list of changed files for a commit — no hunk / line parsing.
- get_
commit_ range_ diff - Return the combined diff across a range of commits.
- get_
single_ file_ diff - Return the diff for a single file within a commit.
- get_
staged_ diff - Return the diff of staged (index) changes against HEAD.
- get_
staged_ file_ list - Lightweight staged file list (no diff content).
- get_
staged_ single_ file_ diff - Return the full diff (with hunks/lines) for a single staged file.
- get_
working_ dir_ diff - Return the diff of unstaged (working-directory) changes against the index.
- get_
working_ dir_ file_ list - Lightweight working-directory file list (no diff content).
- get_
working_ dir_ single_ file_ diff - Return the full diff (with hunks/lines) for a single unstaged file.