Module ops

Module ops 

Diff operations — working-directory, staged, and per-commit diffs.

Functions

get_commit_diff
Return the diff introduced by a specific commit (compared to its first parent).
get_commit_file_list
Return just the list of changed files for a commit — no hunk / line parsing.
get_single_file_diff
Return the diff for a single file within a commit.
get_staged_diff
Return the diff of staged (index) changes against HEAD.
get_working_dir_diff
Return the diff of unstaged (working-directory) changes against the index.