Graph layout computation โ lane-based algorithm for commit graph visualisation.
The algorithm assigns colours per lane (not per OID) so that a linear branch keeps a single consistent colour. New colours are only introduced when a new lane is created for a branch or merge.
Functions
- build_
graph - Build a graph layout for a slice of commits (newest-first).