Log browsing and commit search operations.
Functions
- get_log
- Retrieve the commit log, optionally filtered by author and/or message substring.
- search_
commits - Free-text search across commit summary, full message, author name, author email, and OID.