Module ops

Module ops 

Log browsing and commit search operations.

Functions

file_history
Return commits that touched file_path, newest-first, up to max_count.
get_log
Retrieve the commit log, optionally filtered by author and/or message substring.
search_commits
Free-text search across commit summary, full message, author name, author email, and OID.